akhdefo_functions.Auto_Variogram — Akhdefo software documentation

# akhdefo_functions.Auto_Variogram

akhdefo_functions.Auto_Variogram(path_to_shapefile='', column_attribute='', latlon=False)

  This program automatically selects best variogram model which later can be used to interpolate datapoints.

  ## Parameters

  path_to_shapefile : str type path to shapefile to include data (point data) the shapefile attribute must have x, y or lat, lon columns

  column_attributestr

    Name of shapefile field attribute include data

  ## Returns

  str

    name of best variogram model also figure for plotted variogram models